@@ -219,9 +219,9 @@ function (x, ..., main = NULL, xlab = "Order of Diversity", ylab = NULL, Which =
 autoplot.DivProfile <- 
 function (object, ..., main = NULL, xlab = "Order of Diversity", ylab = NULL, Which = "All", 
           ShadeColor = "grey75", alpha = 0.3, BorderColor = "red", labels = NULL, font.label = list(size=11, face="plain"),
-          col = ggplot2::GeomLine$default_aes$colour,
-          lty = ggplot2::GeomLine$default_aes$linetype,
-          lwd = ggplot2::GeomLine$default_aes$size)
+          col = "black",
+          lty = 1,
+          lwd = 0.5)
 {
   if (Which == "All" | (Which == "Alpha" & is.null(main))) main <- "Total Alpha Diversity"
   if (Which == "All" | (Which == "Alpha" & is.null(ylab))) ylab <- expression(paste(alpha, " diversity"))
